@@ -65,7 +65,7 @@ def main():
     opener = basic_auth_opener(options.site_url, username, password)
     site = SharePointSite(options.site_url, opener)
 
-    if not len(args) == 1:
+    if len(args) == 0:
         sys.stderr.write("You must provide an action. Use -h for more information.\n")
         sys.exit(ExitCodes.NO_SUCH_ACTION)
 
@@ -106,6 +106,8 @@ def main():
                 sys.exit(ExitCodes.MISSING_ARGUMENT)
         xml = site.as_xml(list_names=options.list_names or None,
                           include_field_definitions=options.include_field_definitions)
+    elif action == 'searchprincipal':
+        print site.users.search(args[1], resolve=False)
     elif action == 'shell':
         try:
             from IPython.Shell import IPShellEmbed
